==> rosariosis-v10.2.3.zip: rosariosis-v10.2.3/locale/REFERENCE.md <==
Translations reference
----------------------

Do not forget to add the `.utf8` suffix to the locale code.

| Code  | Language (Country)            | Completed | Translator          |
| ----- | ----------------------------- | --------- | ------------------- |
| af_ZA | Afrikaans (South Africa)      | 32%       |                     |
| ar_AE | Arabic (United Arab Emirates) | **86%**   | Husam Shabeeb, Ali Al-Hassan |
| ar_DZ | Arabic (Saudi Arabia)         | 33%       |                     |
| be_BY | Belarusian (Belarus)          | 32%       |                     |
| bg_BG | Bulgarian (Bulgaria)          | **96%**  | Vanyo Georgiev, Martin Krastev |
| bn_BD | Bengali (Bangladesh)          | 32%       |                     |
| cs_CZ | Czech (Czech Republic)        | 32%       |                     |
| da_DK | Danish (Denmark)              | 32%       |                     |
| de_DE | German (Germany)              | **55%**   | Heike Gutsche       |
| el_GR | Greek (Greece)                | 33%       |                     |
| en_CA | English (Canada)              | 1%        | RDH Associates Inc. |
| es_ES | Spanish (Spain)               | **100%**  | RosarioSIS          |
| et_EE | Estonian (Estonia)            | 33%       |                     |
| fa_IR | Persian (Iran)                | 32%       |                     |
| fi_FI | Finnish (Finland)             | 33%       |                     |
| ga_IE | Irish (Ireland)               | 33%       |                     |
| fr_FR | French (France)               | **100%**  | RosarioSIS, Étienne de Blois |
| gl_GL | Galician                      | 33%       |                     |
| hr_HR | Croatian (Croatia)            | 33%       |                     |
| hu_HU | Hungarian (Hungary)           | 33%       |                     |
| id_ID | Indonesian (Indonesia)        | 33%       |                     |
| is_IS | Icelandic (Iceland)           | 33%       |                     |
| it_IT | Italian (Italy)               | 31%       |                     |
| ja_JP | Japanese (Japan)              | 32%       |                     |
| km_KH | Khmer                         | **86%**   | Lyle Kozloff        |
| ko_KR | Korean (South Korea)          | 31%       |                     |
| lt_LT | Lithuanian (Lithuania)        | 33%       |                     |
| lv_LV | Latvian (Latvia)              | 33%       |                     |
| mk_MK | Macedonian (Macedonia)        | 33%       |                     |
| ms_MY | Malay (Malaysia)              | 32%       |                     |
| nl_NL | Dutch (Netherlands)           | 32%       |                     |
| nn_NO | Norwegian Nynorsk (Norway)    | 33%       |                     |
| pl_PL | Polish (Poland)               | 33%       |                     |
| pt_PT | Portuguese (Portugal)         | 37%       |                     |
| ro_RO | Romanian (Romania)            | 33%       |                     |
| ru_RU | Russian (Russia)              | 32%       |                     |
| sk_SK | Slovak (Slovakia)             | 33%       |                     |
| sl_SI | Slovenian (Slovenia)          | 33%       |                     |
| sq_AL | Albanian (Albania)            | 33%       |                     |
| sr_RS | Serbian (Cyrillic, Bosnia)    | 33%       |                     |
| sv_SE | Swedish (Sweden)              | 33%       |                     |
| th_TH | Thai (Thailand)               | 33%       |                     |
| tr_TR | Turkish (Turkey)              | 32%       |                     |
| uk_UA | Ukrainian (Ukraine)           | 33%       |                     |
| vi_VN | Vietnamese (Vietnam)          | 32%       |                     |
| wa_BE | Walloon (Belgium)             | 33%       |                     |
| zh_CN | Chinese (Simplified, China)   | 32%       |                     |
| zh_TW | Chinese (Traditional, Taiwan) | 33%       |                     |

==> rosariosis-v11.8.5.zip: rosariosis-v11.8.5/locale/REFERENCE.md <==
Translations reference
----------------------

Do not forget to add the `.utf8` suffix to the locale code.

| Code  | Language (Country)            | Completed | Translator          |
| ----- | ----------------------------- | --------- | ------------------- |
| af_ZA | Afrikaans (South Africa)      | 32%       |                     |
| ar_AE | Arabic (United Arab Emirates) | **86%**   | Husam Shabeeb, Ali Al-Hassan |
| ar_DZ | Arabic (Saudi Arabia)         | 33%       |                     |
| be_BY | Belarusian (Belarus)          | 32%       |                     |
| bg_BG | Bulgarian (Bulgaria)          | **96%**  | Vanyo Georgiev, Martin Krastev |
| bn_BD | Bengali (Bangladesh)          | 32%       |                     |
| cs_CZ | Czech (Czech Republic)        | 32%       |                     |
| da_DK | Danish (Denmark)              | 32%       |                     |
| el_GR | Greek (Greece)                | 33%       |                     |
| de_DE | German (Germany)              | **99%**   | Heike Gutsche, @0xD0M1M0 |
| en_CA | English (Canada)              | 1%        | RDH Associates Inc. |
| es_ES | Spanish (Spain)               | **100%**  | RosarioSIS          |
| et_EE | Estonian (Estonia)            | 33%       |                     |
| fa_IR | Persian (Iran)                | 32%       |                     |
| fi_FI | Finnish (Finland)             | 33%       |                     |
| ga_IE | Irish (Ireland)               | 33%       |                     |
| fr_FR | French (France)               | **100%**  | RosarioSIS, Étienne de Blois |
| gl_GL | Galician                      | 33%       |                     |
| hr_HR | Croatian (Croatia)            | 33%       |                     |
| hu_HU | Hungarian (Hungary)           | 33%       |                     |
| id_ID | Indonesian (Indonesia)        | 33%       |                     |
| is_IS | Icelandic (Iceland)           | 33%       |                     |
| it_IT | Italian (Italy)               | 31%       |                     |
| ja_JP | Japanese (Japan)              | 32%       |                     |
| km_KH | Khmer                         | **86%**   | Lyle Kozloff        |
| ko_KR | Korean (South Korea)          | 31%       |                     |
| lt_LT | Lithuanian (Lithuania)        | 33%       |                     |
| lv_LV | Latvian (Latvia)              | 33%       |                     |
| mk_MK | Macedonian (Macedonia)        | 33%       |                     |
| ms_MY | Malay (Malaysia)              | 32%       |                     |
| nl_NL | Dutch (Netherlands)           | 32%       |                     |
| nn_NO | Norwegian Nynorsk (Norway)    | 33%       |                     |
| pl_PL | Polish (Poland)               | 33%       |                     |
| pt_BR | Portuguese (Brazil)           | **100%**  | Emerson Barros      |
| pt_PT | Portuguese (Portugal)         | 37%       |                     |
| ro_RO | Romanian (Romania)            | 33%       |                     |
| ru_RU | Russian (Russia)              | 32%       |                     |
| sk_SK | Slovak (Slovakia)             | 33%       |                     |
| sl_SI | Slovenian (Slovenia)          | **76%**   | AT group            |
| sq_AL | Albanian (Albania)            | 33%       |                     |
| sr_RS | Serbian (Cyrillic, Bosnia)    | 33%       |                     |
| sv_SE | Swedish (Sweden)              | 33%       |                     |
| th_TH | Thai (Thailand)               | 33%       |                     |
| tr_TR | Turkish (Turkey)              | 32%       |                     |
| uk_UA | Ukrainian (Ukraine)           | 33%       |                     |
| vi_VN | Vietnamese (Vietnam)          | **99%**   | Steven M. Haag & Trân Thi Kim Thanh |
| wa_BE | Walloon (Belgium)             | 33%       |                     |
| zh_CN | Chinese (Simplified, China)   | 32%       |                     |
| zh_TW | Chinese (Traditional, Taiwan) | 33%       |                     |
